==> tuyaos_demo_ipc_1.0.0.tar.gz: tuyaos_demo_ipc/src/tuya_ipc_tmm_demo.c <==
/*********************************************************************************
  *Copyright(C),2015-2020,
  *TUYA
  *www.tuya.comm
  *FileName:    tuya_ipc_tmm_demo
**********************************************************************************/

#include <stdio.h>
#include "tuya_ipc_p2p.h"

INT_T tmm_status = 0;
extern CHAR_T g_local_key[64];
extern CHAR_T g_remote_id[64];
extern BOOL_T enable_tmm_link;


int get_tmm_status()
{
    return tmm_status;
}

VOID *thread_tmm_proc(VOID *arg)
{
    int tmm_flag = 0;  
    INT_T handle = 0;
    enable_tmm_link = TRUE;
    
    while (1) {
        tmm_flag = get_tmm_status();
        if(tmm_flag) {
            int ret = 0;
            for(int i=0; i<20; i++) {
                tuya_ipc_p2p_client_connect(&handle, g_remote_id, g_local_key);
              
                tuya_ipc_p2p_client_set_video_clarity_standard(handle);
           
                tuya_ipc_p2p_client_start_prev(handle);
                
                tuya_ipc_p2p_client_start_audio(handle);
                
                tuya_ipc_p2p_client_video_send_start(handle);
            
                tuya_ipc_p2p_client_audio_send_start(handle);
                
                tuya_ipc_p2p_client_stop_prev(handle);
              
                tuya_ipc_p2p_client_stop_audio(handle);
                
                tuya_ipc_p2p_client_video_send_stop(handle);
             
                tuya_ipc_p2p_client_audio_send_stop(handle);
                
                ret = tuya_ipc_p2p_client_disconnect(handle);
                sleep(2);
                if(ret == OPRT_OK){
                    printf("disconnect success!!!!!!!!!!\n");
                }
            }
            sleep(20);
        } else {
            sleep(2);
        }
    }

    return NULL;
}

==> tuyaos_demo_ipc_1.0.4.tar.gz: tuyaos_demo_ipc/src/tuya_ipc_tmm_demo.c <==
/*********************************************************************************
  *Copyright(C),2015-2020,
  *TUYA
  *www.tuya.comm
  *FileName:    tuya_ipc_tmm_demo
**********************************************************************************/

#include <stdio.h>
#include "tuya_ipc_p2p.h"
#include "tuya_ipc_log_demo.h"

INT_T tmm_status = 0;
extern CHAR_T g_local_key[64];
extern CHAR_T g_remote_id[64];
extern BOOL_T enable_tmm_link;


int get_tmm_status()
{
    return tmm_status;
}

VOID *thread_tmm_proc(VOID *arg)
{
    int tmm_flag = 0;  
    INT_T handle = 0;
    enable_tmm_link = TRUE;
    
    while (1) {
        tmm_flag = get_tmm_status();
        if(tmm_flag) {
            int ret = 0;
	    int i;
            for(i=0; i<20; i++) {
                tuya_ipc_p2p_client_connect(&handle, g_remote_id, g_local_key);
              
                tuya_ipc_p2p_client_set_video_clarity_standard(handle);
           
                tuya_ipc_p2p_client_start_prev(handle);
                
                tuya_ipc_p2p_client_start_audio(handle);
                
                tuya_ipc_p2p_client_video_send_start(handle);
            
                tuya_ipc_p2p_client_audio_send_start(handle);
                
                tuya_ipc_p2p_client_stop_prev(handle);
              
                tuya_ipc_p2p_client_stop_audio(handle);
                
                tuya_ipc_p2p_client_video_send_stop(handle);
             
                tuya_ipc_p2p_client_audio_send_stop(handle);
                
                ret = tuya_ipc_p2p_client_disconnect(handle);
                sleep(2);
                if(ret == OPRT_OK){
                    PR_INFO("disconnect success!!!!!!!!!!\n");
                }
            }
            sleep(20);
        } else {
            sleep(2);
        }
    }

    return NULL;
}
